//
//  SessionStateLEDViewController.swift
//  SampleApp
//
//  Created by Federico Zanetello on 5/8/19.
//  Copyright © 2019 David Zhang. All rights reserved.
//

import UIKit
import AmitySDK
import Combine
import SwiftUI

/// Responsible to update the LED status, according to the given `AmityClient` `connectionStatus`
class SessionStateLEDViewController: UIViewController {
    
    @IBOutlet private weak var sessionStateImageView: UIImageView!
    
    private var disposeBag: Set<AnyCancellable> = []

    override func viewDidLoad() {
        super.viewDidLoad()
        
        AmityManager.shared.client!
            .$sessionState
            .map(\.color)
            .assign(to: \.tintColor, on: sessionStateImageView)
            .store(in: &disposeBag)
        
        sessionStateImageView.isUserInteractionEnabled = true
        let tapGesture = UITapGestureRecognizer(target: self, action: #selector(presentSessionStateLog))
        sessionStateImageView.addGestureRecognizer(tapGesture)
        
    }
    
    @objc private func presentSessionStateLog() {
        let vc = UIHostingController(rootView: SessionStateLogPage())
        present(vc, animated: true)
    }
    
}


extension SessionState {
    
    var color: UIColor? { UIColor(named: colorName) }

    var colorName: String {
        switch self {
        case .notLoggedIn:
            return "AmityGray"
        case .establishing:
            return "AmityOrange"
        case .established:
            return "AmityGreen"
        case .tokenExpired:
            return "AmitySalmon"
        case .terminated:
            return "AmityRed"
        }
    }
    
    var colorEmoji: String {
        switch self {
        case .notLoggedIn:
            return "⬜️"
        case .establishing:
            return "🟧"
        case .established:
            return "🟩"
        case .tokenExpired:
            return "🟪"
        case .terminated:
            return "🟥"
        }
    }
    
}
