//
//  CheckPermissionView.swift
//  SampleApp
//
//  Created by Manuchet Rungraksa on 8/12/2566 BE.
//  Copyright © 2566 BE David Zhang. All rights reserved.
//

import Foundation
import SwiftUI
import AmitySDK

struct CheckPermissionView: View {
    @State var enteredPermission: String = ""
    @State var permissionStatus: String = "Select any permission to check"
    @State var permissionType: PermissionType
    
    @State var isPresented: Bool = false
    @State var enteredText: String = ""
    @State var isTextValid: Bool = false
    @State var allPermission: [AmityPermission] = AmityPermission.allCases
    @State var selectedPermission: AmityPermission = .muteChannel
    
    @Environment(\.presentationMode) var presentationMode
    
    enum PermissionType {
        case community(id: String)
        case channel(id: String)
        case user
    }
    
    var body: some View {
        VStack {
            
            Picker("Select permission", selection: $selectedPermission) {
                
                ForEach(allPermission, id: \.self) {
                    Text($0.identifier)
                }
            }
            .pickerStyle(MenuPickerStyle())
            .padding()
            
            Text("\(permissionStatus)")
            
            HStack {
                Button("Check permission") {
                    self.isTextValid = !enteredText.isEmpty
                    
                    switch permissionType {
                    case .community(let id):
                        AmityManager.shared.client?.hasPermission(selectedPermission, forCommunity: id, completion: { success in
                            permissionStatus = success ? "Has permission" : "Don't have permission"
                        })
                    case .channel(let id):
                        AmityManager.shared.client?.hasPermission(selectedPermission, forCommunity: id, completion: { success in
                            permissionStatus = success ? "Has permission" : "Don't have permission"
                        })
                    case .user:
                        AmityManager.shared.client?.hasPermission(selectedPermission, completion: { success in
                            permissionStatus = success ? "Has permission" : "Don't have permission"
                        })
                    }
                }
                .padding()
                
                Button("Cancel") {
                    presentationMode.wrappedValue.dismiss()
                }
                .padding()
            }
        }
        .padding()
        .background(Color.white)
        .cornerRadius(10)
        
    }
}

