//
//  StoryListView.swift
//  SampleApp
//
//  Created by Manuchet Rungraksa on 4/12/2566 BE.
//  Copyright © 2566 BE David Zhang. All rights reserved.
//

import Foundation
import SwiftUI
import AmitySDK

struct StoryListView: View {
    
    @ObservedObject var viewModel: StoryListViewModel
    
    @Environment(\.navigationController) var navigationController
    
    @State private var memberType = AmityCommunityQueryFilter.all
    @State private var sortType = AmityStoryQuerySortOption.lastCreated
    @State private var includeDeleted = false
    @State private var categoryId = ""
    
    @State private var showCategoryListScreen = false
    @State private var showCreateScreen = false
    @State private var forceScrollToTop = false
    @State private var selection: String?
        
    var body: some View {
        VStack {
            StoriesQueryMenu
            
            StoryCollectionView(storyCollection: viewModel.storyCollection, storyTargetObject: viewModel.storyTargetObject, viewModel: viewModel)
            
            Spacer()
        }
        .navigationBarTitle(Text(viewModel.pageTitle), displayMode: .inline)
        .toolbar {
            ToolbarItemGroup(placement: .navigationBarTrailing) {
                NavigationLink(destination: CreateStoryView(feedManager: viewModel.storyManager, communityId: viewModel.targetId), isActive: $showCreateScreen) {
                    Button(action: {
                        self.showCreateScreen = true
                    }, label: {
                        Image(systemName: "plus")
                    })
                }
            }
        }
        .onAppear(perform: {
            selection = nil
            showCreateScreen = false
            
            UITableViewCell.appearance().selectionStyle = .none
            UITableView.appearance().separatorStyle = .none
            UITextField.appearance().clearButtonMode = .always
        })
        
    }
    
    @ViewBuilder
    var StoriesQueryMenu: some View {
        VStack(alignment: .leading) {
            HStack {
                Text("Sort By")
                    .font(.caption)
                Spacer()
                Picker("Sort Type", selection: $sortType) {
                    Text("Last created").tag(AmityStoryQuerySortOption.lastCreated)
                    Text("First created").tag(AmityStoryQuerySortOption.firstCreated)
                }
                .pickerStyle(.segmented)
            }
            
            // Query Button
            HStack {
                Spacer()
                
                Button("Get Stories") {
                    forceScrollToTop.toggle()
                    viewModel.setSort(sortType)
                    viewModel.queryStory()
                    viewModel.queryStoryTarget()
                                        
                }.buttonStyle(.bordered)
                
                Spacer()
            }
        }
        .padding()
    }
}
