//
//  StoryManager.swift
//  SampleApp
//
//  Created by Manuchet Rungraksa on 4/12/2566 BE.
//  Copyright © 2566 BE David Zhang. All rights reserved.
//

import Foundation
import AmitySDK

class StoryManager {
    
    var storyRepository = AmityStoryRepository(client: AmityManager.shared.client!)
    
    func createStory(mediaURL: URL?,
                     type: AmityStoryType,
                     hyperlink: AmityHyperLinkItem?,
                     communityId: String?,
                     metadata: [String: Any]?,
                     imageDisplayMode: AmityStoryImageDisplayMode) async throws -> AmityStory? {
        
        let targetType: AmityStoryTargetType = .community
        
        var story: AmityStory?
        
        var storyItems = [AmityStoryItem]()
        if let hyperlink {
            storyItems.append(hyperlink)
        }
        
        if let mediaURL, let communityId {
            switch type {
            case .image:
                let options = AmityImageStoryCreateOptions(targetType: targetType, tartgetId: communityId, imageFileURL: mediaURL, metadata: nil, items: storyItems, imageDisplayMode: imageDisplayMode)
                story = try await storyRepository.createImageStory(options: options)
                return story
            case .video:
                let options = AmityVideoStoryCreateOptions(targetType: targetType, tartgetId: communityId, videoFileURL: mediaURL, metadata: nil, items: storyItems)
                story = try await storyRepository.createVideoStory(options: options)
                return story
            default:
                return nil
            }
        } else {
            return story
        }
        
    }
    
    @MainActor
    func getActiveStories(communityId: String, sortOptions: AmityStoryQuerySortOption) -> AmityCollection<AmityStory>  {
        let targetType: AmityStoryTargetType = .community
        
        return storyRepository.getActiveStoriesByTarget(targetType: targetType, targetId: communityId, sortOption: sortOptions)
    }
    
    @MainActor
    func getStoryTarget(communityId: String) -> AmityObject<AmityStoryTarget>  {
        let targetType: AmityStoryTargetType = .community

        return storyRepository.getStoryTarget(targetType: targetType, targetId: communityId)
    }
    
    func deleteStory(storyId: String, hardDelete: Bool) async throws {
        if hardDelete {
            try await storyRepository.hardDeleteStory(storyId: storyId)
        } else {
            try await storyRepository.softDeleteStory(storyId: storyId)
        }
    }
    
}
