//
//  StreamListViewController.swift
//  SampleAppLiveVideo
//
//  Created by Nutchaphon Rewik on 19/10/2563 BE.
//  Copyright © 2563 Amity. All rights reserved.
//

import UIKit
import AmitySDK

class StreamListViewController: UIViewController {
    
    var liveStreamCollection: AmityCollection<AmityStream>?
    var token: AmityNotificationToken?
    
    var willEnterForgroundToken: NSObjectProtocol?
    
    private var selectedStream: AmityStream?
    
    @IBOutlet private weak var tableView: UITableView!
    @IBOutlet private weak var emptyView: UIView!
    
    deinit {
        token = nil
        willEnterForgroundToken = nil
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        title = "Live Videos"
        tableView.register(LiveStreamCell.nib(), forCellReuseIdentifier: LiveStreamCell.identifier)
        setupDataSource()
        observeAppForegroundEvent()
        
        NotificationCenter.default.addObserver(forName: Notification.Name.updateUser, object: nil, queue: nil) { [weak self] notification in
            
            self?.setupDataSource()
            self?.observeAppForegroundEvent()
        }
    }
    
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        switch segue.identifier {
        case "watchLiveStream":
            if let playerViewController = segue.destination as? PlayerViewController{
                playerViewController.streamToWatch = selectedStream
            }
        default:
            break
        }
    }
    
    func observeAppForegroundEvent() {
        willEnterForgroundToken = NotificationCenter.default.addObserver(forName: UIApplication.willEnterForegroundNotification, object: nil, queue: nil) { [weak self] notification in
            guard let strongSelf = self else { return }
            // The user can close the app into the background.
            // When the app goes into foreground, refresh the collection again.
            strongSelf.setupDataSource()
        }
    }
    
    private func setupDataSource() {
        
        // Create query object.
        let query = AmityStreamCollectionQuery()
        query.includeStatus(.live)
        
        // Get colelction from the query that we craeted.
        liveStreamCollection = AppManager.shared.streamRepository?.getStreams(from: query)
        token = liveStreamCollection?.observe({ [weak self] collection, change, error in
            // Whenever the collection is updated, trigger to update the data source.
            self?.updateDataSource()
        })
        
        // Trigger data source update for the first time the collection is created.
        updateDataSource()
    }
    
    private func updateDataSource() {
        
        let hasDataToShow: Bool
        if let liveStreamCollection = liveStreamCollection, liveStreamCollection.count() > 0 {
            hasDataToShow = true
        } else {
            hasDataToShow = false
        }
        
        emptyView.isHidden = hasDataToShow
        tableView.isHidden = !hasDataToShow
        
        tableView.reloadData()
        
    }
    
}

extension StreamListViewController: UITableViewDataSource {
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return Int(liveStreamCollection?.count() ?? 0)
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        return tableView.dequeueReusableCell(withIdentifier: LiveStreamCell.identifier, for: indexPath)
    }
    
}

extension StreamListViewController: UITableViewDelegate {
    
    func tableView(_ tableView: UITableView, willDisplay cell: UITableViewCell, forRowAt indexPath: IndexPath) {
        
        let liveStreamCell = cell as! LiveStreamCell
        
        if let streamObject = liveStreamCollection?.object(at: indexPath.row) {
            liveStreamCell.configure(with: streamObject)
        } else {
            cell.textLabel?.text = "Not Found"
            cell.detailTextLabel?.text = "..."
        }
        
        // Load next page, when showing the last item in the collection.
        if let liveStreamCollection = liveStreamCollection, indexPath.row == liveStreamCollection.count() - 1 {
            liveStreamCollection.nextPage()
        }
        
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        return LiveStreamCell.height
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        
        tableView.deselectRow(at: indexPath, animated: true)
        
        if let stream = liveStreamCollection?.object(at: indexPath.row) {
            AppManager.shared.presentLiveVideo(forStreamId: stream.streamId)
        }
        
    }
    
}
